Documentation
¶
Overview ¶
Package awsconfigfile contains logic to template ~/.aws/config files based on Common Fate access rules.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultProfileNameTemplate = "{{ .AccountName }}/{{ .RoleName }}"
Functions ¶
func DefaultSharedConfigFilename ¶
func DefaultSharedConfigFilename() string
DefaultSharedConfigFilename returns the AWS SDK's default file path for the shared config file. It is vendored from the AWS Go SDK v2 to prevent importing the entire module.
Builds the shared config file path based on the OS's platform.
- Linux/Unix: $HOME/.aws/config
- Windows: %USERPROFILE%\.aws\config
Types ¶
type AccountProfile ¶
type Generator ¶
type Generator struct {
Sources []Source
Config *ini.File
NoCredentialProcess bool
ProfileNameTemplate string
Prefix string
// PruneStartURLs is a slice of AWS SSO start URLs which profiles are being generated for.
// Existing profiles with these start URLs will be removed if they aren't found in the Profiles field.
PruneStartURLs []string
SessionName string
SSOScopes []string
PreferRoles []string
Verbose bool
DefaultRegion string
}
Generator generates AWS profiles for ~/.aws/config. It reads profiles from sources and merges them with an existing ini config file.
type MergeOpts ¶
type MergeOpts struct {
Config *ini.File
Prefix string
Profiles []SSOProfile
SectionNameTemplate string
NoCredentialProcess bool
// PruneStartURLs is a slice of AWS SSO start URLs which profiles are being generated for.
// Existing profiles with these start URLs will be removed if they aren't found in the Profiles field.
PruneStartURLs []string
SessionName string
SSOScopes []string
PreferRoles []string
Verbose bool
DefaultRegion string
}
type SSOProfile ¶
Click to show internal directories.
Click to hide internal directories.